/* Define if the C++ compiler supports BOOL */
#undef HAVE_BOOL

#undef VERSION

#undef PACKAGE

/* defines if having libz */
#undef HAVE_LIBZ

/* defines if having libgif (always 1) */
#undef HAVE_LIBGIF

/* defines if having libjpeg (always 1) */
#undef HAVE_LIBJPEG

/* defines if having libpng */
#undef HAVE_LIBPNG

/* defines which to take for ksize_t */
#undef ksize_t

/* define if you have setenv */
#undef HAVE_FUNC_SETENV

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES    

/* Define if you need the GNU extensions to compile */
#undef _GNU_SOURCE

/* Define if you want to see voluminous trace output */
#undef WANT_TRACE_OUTPUT

/* Define to the name of the file that communication with gdb
   should be logged to; undefine it for no logging */
#undef GDB_TRANSCRIPT

/* Define if placement new works */
#undef HAVE_PLACEMENT_NEW
